.. image:: https://badge.fury.io/py/tox.svg
  :target: https://badge.fury.io/py/tox
  :alt: Latest version on PyPi
.. image:: https://img.shields.io/pypi/pyversions/tox.svg
  :target: https://pypi.org/project/tox/
  :alt: Supported Python versions
.. image:: https://travis-ci.org/tox-dev/tox.svg?branch=master
  :target: https://travis-ci.org/tox-dev/tox
  :alt: Travis-CI build status
.. image:: https://ci.appveyor.com/api/projects/status/2pw2n1wki9terluu?svg=true
  :target: https://ci.appveyor.com/project/ToxDev/tox
  :alt: Appveyor build status
.. image:: https://codecov.io/gh/tox-dev/tox/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/tox-dev/tox
  :alt: Code coverage Status
.. image:: https://readthedocs.org/projects/tox/badge/?version=latest
  :target: http://tox.readthedocs.io/en/latest/?badge=latest
  :alt: Documentation status
.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
  :target: https://github.com/ambv/black
  :alt: Code style: black

tox automation project
======================

**vision: standardize testing in Python**

tox aims to automate and standardize testing in Python. It is part of a larger vision of easing the packaging, testing and release process of Python software.

What is tox?
============

tox is a generic virtualenv management and test command line tool you can use for:

* checking your package installs correctly with different Python versions and
  interpreters

* running your tests in each of the environments, configuring your test tool of choice

* acting as a frontend to Continuous Integration servers, greatly
  reducing boilerplate and merging CI and shell-based testing.

For more information and the repository please see:

- home and docs: https://tox.readthedocs.org

- repository: https://github.com/tox-dev/tox
